@@ -2,12 +2,15 @@ import re
 import requests
 import pandas as pd
 from datetime import datetime
+from . import errors
+
 
 def _to_unix_epoch(date_string):
     # Get uniq epoch time as integer
     unix_epoch = datetime.strptime(date_string, "%Y-%m-%d")
     tm = (unix_epoch - datetime(1970, 1, 1)).total_seconds()
-    return int(tm)   
+    return int(tm)
+
 
 def _to_unix_w_freq(sample_len, base_time, base_type):
     """
@@ -17,7 +20,7 @@ def _to_unix_w_freq(sample_len, base_time, base_type):
         Enter positive beg_tm as base_time to find end date.
     """
     tm_freq, tm_unit = re.findall(r'(\d+)(\w+?)', sample_len)[0]
-    tm_freq = int(tm_freq) *(-1) if base_type == 'End' else int(tm_freq)
+    tm_freq = int(tm_freq) * (-1) if base_type == 'End' else int(tm_freq)
 
     base_timestamp = pd.Timestamp(base_time, unit='s')
 
@@ -30,8 +33,9 @@ def _to_unix_w_freq(sample_len, base_time, base_type):
     elif str.upper(tm_unit) == 'Y':
         new_time = base_timestamp + pd.DateOffset(years=tm_freq)
     else:
-        print("Unknown time unit, accepts: D, W, M, Y")
-    return(int(new_time.timestamp()))
+        raise errors.MoabRequestError("Unknown time unit, accepts: D, W, M, Y")
+    return (int(new_time.timestamp()))
+
 
 def _get_unix_dates(sample_len, start_dt, end_dt):
     # User provided sample length ...
@@ -44,12 +48,12 @@ def _get_unix_dates(sample_len, start_dt, end_dt):
 
     # ... and provided start date --> find end date using sample length
     elif (end_dt is None) & (start_dt is not None):
-        start = _to_unix_epoch(start_dt)   
+        start = _to_unix_epoch(start_dt)
         end = _to_unix_w_freq(sample_len, start, 'Start')
 
     # ... and provided end date --> find start date using sample length
     elif (end_dt is not None) & (start_dt is None):
-        end = _to_unix_epoch(end_dt)   
+        end = _to_unix_epoch(end_dt)
         start = _to_unix_w_freq(sample_len, end, 'End')
 
     # ... and provided start and end date --> ignore sample length
@@ -57,4 +61,4 @@ def _get_unix_dates(sample_len, start_dt, end_dt):
         end = _to_unix_epoch(end_dt)
         start = _to_unix_epoch(start_dt)
 
-    return(start, end)
\ No newline at end of file
+    return (start, end)
